@@ -63,7 +63,6 @@ from ecowitt2mqtt.const import (
     DATA_POINT_SOLARRADIATION_PERCEIVED,
     DATA_POINT_TF_CO2,
     DATA_POINT_THERMAL_PERCEPTION,
-    DATA_POINT_TOTAL_AIN,
     DATA_POINT_TOTAL_RAIN,
     DATA_POINT_UV,
     DATA_POINT_WEEKLY_RAIN,
@@ -347,10 +346,6 @@ ENTITY_DESCRIPTIONS = {
         device_class=DeviceClass.TEMPERATURE,
         state_class=StateClass.MEASUREMENT,
     ),
-    DATA_POINT_TOTAL_AIN: EntityDescription(
-        icon="mdi:water",
-        state_class=StateClass.TOTAL_INCREASING,
-    ),
     DATA_POINT_UV: EntityDescription(
         icon="mdi:weather-sunny",
         state_class=StateClass.MEASUREMENT,
@@ -383,14 +378,24 @@ STATE_CLASS_OVERRIDES = {
     DATA_POINT_YRAIN_PIEZO: StateClass.TOTAL,
 }
 
+STATE_UNKNOWN = "unknown"
+
 
 def get_availability_payload(data_point: CalculatedDataPoint) -> str:
-    """Get the availability payload for a data point."""
-    if data_point.value is None:
-        return AVAILABILITY_OFFLINE
+    """Get the availability payload for a data point.
+
+    Right now, this is hardcoded to always available.
+    """
     return AVAILABILITY_ONLINE
 
 
+def get_state_payload(data_point: CalculatedDataPoint) -> DataValueType:
+    """Get the state payload for a data point."""
+    if data_point.value is None:
+        return STATE_UNKNOWN
+    return data_point.value
+
+
 class HomeAssistantDiscoveryPublisher(MqttPublisher):
     """Define an MQTT publisher for the MQTT Discovery standard."""
 
@@ -495,7 +500,10 @@ class HomeAssistantDiscoveryPublisher(MqttPublisher):
                         discovery_payload.payload["json_attributes_topic"],
                         data_point.attributes,
                     ),
-                    (discovery_payload.payload["state_topic"], data_point.value),
+                    (
+                        discovery_payload.payload["state_topic"],
+                        get_state_payload(data_point),
+                    ),
                 ):
                     tasks.append(
                         asyncio.create_task(
